Chatbot Library
===
Abstract:xxx
## Papar Information
- Title:  `paper name`


## Install & Dependence
- python
- pytorch
- numpy


## Directory Hierarchy
```
|—— chatbotlib
|    |—— chatbot.py
|    |—— setup.py
|    |—— static
|        |—— css
|            |—— style.css
|        |—— js
|            |—— script.js
|    |—— templates
|        |—— index.html
|    |—— webapp.py
|    |—— __init__.py
|—— MANIFEST.in
```
## Code Details
### Tested Platform
- software
  ```
  OS: Debian unstable (May 2021), Ubuntu LTS
  Python: 3.8.5 (anaconda)
  PyTorch: 1.7.1, 1.8.1
  ```
- hardware
  ```
  CPU: Intel Xeon 6226R
  GPU: Nvidia RTX3090 (24GB)
  ```

